@@ -23,6 +23,8 @@ using namespace KAndroidExtras;
 #include <QtAndroid>
 #endif
 
+#include <csignal>
+
 void DevelopmentModeController::enablePublicTransportLogging()
 {
 #ifdef Q_OS_ANDROID
@@ -84,3 +86,8 @@ void DevelopmentModeController::clearOsmTileCache()
     }
     QDir(base + QLatin1String("/17")).removeRecursively();
 }
+
+void DevelopmentModeController::crash()
+{
+    std::raise(SIGSEGV);
+}
