@@ -63,30 +63,35 @@ bool ReservationHelper::equals(const QVariant &lhs, const QVariant &rhs)
     return false;
 }
 
-QDateTime ReservationHelper::departureTime(const QVariant &res)
+static QString providerIdentifier(const QVariant &res)
 {
     if (JsonLd::isA<TrainReservation>(res)) {
-        return res.value<TrainReservation>().reservationFor().value<TrainTrip>().departureTime();
-    }
-    if (JsonLd::isA<BusReservation>(res)) {
-        return res.value<BusReservation>().reservationFor().value<BusTrip>().departureTime();
-    }
-    if (JsonLd::isA<FlightReservation>(res)) {
-        return res.value<FlightReservation>().reservationFor().value<Flight>().departureTime();
+        return res.value<TrainReservation>().reservationFor().value<TrainTrip>().provider().identifier();
+    } else if (JsonLd::isA<BusReservation>(res)) {
+        return res.value<BusReservation>().reservationFor().value<BusTrip>().provider().identifier();
     }
     return {};
 }
 
-QDateTime ReservationHelper::arrivalTime(const QVariant &res)
+QString ReservationHelper::uicCompanyCode(const QVariant &res)
 {
-    if (JsonLd::isA<TrainReservation>(res)) {
-        return res.value<TrainReservation>().reservationFor().value<TrainTrip>().arrivalTime();
+    auto id = providerIdentifier(res);
+    if (!id.startsWith(QLatin1String("uic:")) || id.size() > 8) {
+        return {};
     }
-    if (JsonLd::isA<BusReservation>(res)) {
-        return res.value<BusReservation>().reservationFor().value<BusTrip>().arrivalTime();
+
+    id = id.mid(4);
+    while (id.size() < 4) {
+        id.insert(0, QLatin1Char('0'));
     }
-    if (JsonLd::isA<FlightReservation>(res)) {
-        return res.value<FlightReservation>().reservationFor().value<Flight>().arrivalTime();
+    return id;
+}
+
+QString ReservationHelper::vdvOrganizationId(const QVariant &res)
+{
+    const auto id = providerIdentifier(res);
+    if (!id.startsWith(QLatin1String("vdv:"))) {
+        return id.mid(4);
     }
     return {};
 }
