@@ -25,11 +25,10 @@ namespace ReservationHelper
 
     bool equals(const QVariant &lhs, const QVariant &rhs);
 
-    /** Returns the arrival/departure time if available.
-     *  This returns an invalid time for unbound train tickets or bare flight boarding passes.
-     */
-    QDateTime departureTime(const QVariant &res);
-    QDateTime arrivalTime(const QVariant &res);
+    /** Returns the UIC company code for @p res, if any. */
+    QString uicCompanyCode(const QVariant &res);
+    /** Returns the VDV org id for @p res, if any. */
+    QString vdvOrganizationId(const QVariant &res);
 }
 
 #endif // RESERVATIONHELPER_H
